#!/usr/bin/env python
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : rpm-rebuilder
# File            : extract-requires.py
# Version         : $Id: extract-requires.py,v 1.2 2000/10/01 18:01:09 flepied Exp $
# Author          : Frederic Lepied
# Created On      : Sat Aug  5 20:36:22 2000
#---------------------------------------------------------------

import sys
import commands
import re
import os
import rpm

import site

if os.path.isdir("../rpmlint"):
    site.addsitedir("../rpmlint")
elif os.path.isdir("/usr/share/rpmlint"):
    site.addsitedir("/usr/share/rpmlint")
    
import Pkg

so_regex=re.compile("(.*\.so).*")
src_regex=re.compile("(.*)-[^-]+-[^-]+")
lib_paths = ("/usr/lib/", "/usr/X11R6/lib/")

def extractBuildReq(p):
    res=so_regex.search(p)
    if res:
        file=res.group(1)
        for path in lib_paths:
            if os.path.isfile(path + file):
                ret=commands.getstatusoutput("rpm -qf " +  path + file)
                if ret[0] == 0 and ret[1] != '':
                    ret=commands.getstatusoutput("rpm -q --queryformat %{NAME} " + ret[1])
                    if ret[0] == 0 and ret[1] != 'glibc-devel':
                        return ret[1]
    return None

def addDep(all, l, name):
    for dep in all:
        d=extractBuildReq(dep[0])
        if d and not d in l and d != name and d != name + "-devel":
            l.append(d)
    
def extractInfo(files):
    assoc={}
    src_assoc={}
    for f in files:
        sys.stderr.write("reading %s\n" % f)
        try:
            p = Pkg.Pkg(f, "/tmp")
        except:
            sys.stderr.write("error reading %s\n" % f)
            continue
        
        srcname=p[rpm.RPMTAG_SOURCERPM]
        name=p[rpm.RPMTAG_NAME]
        res=src_regex.search(srcname)
        if res:
            srcname=res.group(1)
        try:
            l=assoc[srcname]
        except KeyError:
            l=[]
        addDep(p.requires(), l, name)
        addDep(p.prereq(), l, name)
        p.cleanup()
        assoc[srcname]=l
        src_assoc[name]=srcname
    sys.stdout.write("dep=")
    sys.stdout.write(repr(assoc))
    sys.stdout.write("\n")
    
if __name__ == '__main__':
    extractInfo(sys.argv[1:])
    
# extract-requires.py ends here
